@@ -4,8 +4,10 @@ import sys,time,re
 import osso
 import webbrowser
 from PyQt4 import QtGui,QtCore
+from PyQt4.QtCore import *
 from PyQt4.QtGui import *
 from pyRadio_ui import *
+from pyRadio_ui_portrait import *
 from radioplayer import RadioPlayer
 
 import gobject, dbus
@@ -16,12 +18,12 @@ __title__ = "Pandora"
 
 class snooze(QtCore.QThread):
 	__pyqtSignals__ = ( "shutdown" )
-	def __init__(self,time,cont=None):
-		self.time = time
+	def __init__(self,ktime,cont=None):
+		self.ktime = ktime
 		self.cont = cont
 		QtCore.QThread.__init__(self)
 	def run(self):
-		time.sleep(self.time*60)
+		time.sleep(self.ktime*60)
 		if self.cont:
 			self.emit(QtCore.SIGNAL("shutdown"))
 
@@ -85,36 +87,64 @@ class Panda(QtGui.QMainWindow):
 		self.ui = None
 		self.pandora = None
 		self.die = False
+		self.authenticated = False
 		self.c = Config()
 		self.c.load()
 		self.player = RadioPlayer()
 		self.player.start()
-		if not self.c.lastplayed == "":
-			self.player.playStation = self.c.lastplayed
 		self.ui = Ui_pyRadio()
 		self.ui.setupUi(self)
+		if not self.c.lastplayed == "":
+			self.player.playStation = self.c.lastplayed
+		try :
+			self.setAttribute(Qt.WA_Maemo5AutoOrientation, 1)
+			self.connect(QApplication.desktop(), SIGNAL("resized(int)"), self.orientationChanged );
+			print" Auto rotation on"
+		except:print "could not autorotate on"
 		self.skip = 0
-		self.ui.btnPlay.setEnabled( False )
-		self.ui.listStations.setEnabled( False )
-		self.ui.btnLove.setEnabled( False )
-		self.ui.btnHate.setEnabled( False )
-		self.ui.btnSleep.setEnabled( False )
-		self.ui.btnNext.setEnabled( False )
 		self.s = snooze(0)
 		self.createStations = []
 		self.count = 0
-
+		self.connect_signals()
 		self.auth()
-		sysbus = dbus.SystemBus()
-		self.fmtx = sysbus.get_object('com.nokia.FMTx', '/com/nokia/fmtx/default', False)
-		self.fmtx_iface = dbus.Interface(self.fmtx, dbus_interface='org.freedesktop.DBus.Properties')
+		try :
+			sysbus = dbus.SystemBus()
+			self.fmtx = sysbus.get_object('com.nokia.FMTx', '/com/nokia/fmtx/default', False)
+			self.fmtx_iface = dbus.Interface(self.fmtx, dbus_interface='org.freedesktop.DBus.Properties')
 
-		state = self.fmtx_iface.Get("com.nokia.FMTx.Device", "state")
-		if state == 'enabled':
-			self.ui.actionEnable_FM_Radio.setText(QtGui.QApplication.translate("pyRadio", "Disable FM Tx", None, QtGui.QApplication.UnicodeUTF8))
+			state = self.fmtx_iface.Get("com.nokia.FMTx.Device", "state")
+			if state == 'enabled':
+				self.ui.actionEnable_FM_Radio.setText(QtGui.QApplication.translate("pyRadio", "Disable FM Tx", None, QtGui.QApplication.UnicodeUTF8))
+			else:
+				self.ui.actionEnable_FM_Radio.setText(QtGui.QApplication.translate("pyRadio", "Enable FM Tx", None, QtGui.QApplication.UnicodeUTF8))
+		except: print "Not N900."
+
+	def orientationChanged ( self ):
+		screenGeometry=QApplication.desktop().screenGeometry();
+		if screenGeometry.width() > screenGeometry.height():
+			self.ui = Ui_pyRadio()
+			self.ui.setupUi(self)
+			self.connect_signals()
+			if not self.player.curSong == 0:
+				self.setUi ( self.player.curSong )
+				self.buildPlaylist()
 		else:
-			self.ui.actionEnable_FM_Radio.setText(QtGui.QApplication.translate("pyRadio", "Enable FM Tx", None, QtGui.QApplication.UnicodeUTF8))
-			
+			self.ui = Ui_pyRadio_portrait()
+			self.ui.setupUi(self)
+			self.connect_signals()
+			if not self.player.curSong == 0:
+				self.setUi ( self.player.curSong )
+				self.buildPlaylist()
+		print "Orientation Changed"
+
+	def connect_signals( self ):
+		if not self.authenticated:
+			self.ui.btnPlay.setEnabled( False )
+			self.ui.listStations.setEnabled( False )
+			self.ui.btnLove.setEnabled( False )
+			self.ui.btnHate.setEnabled( False )
+			self.ui.btnSleep.setEnabled( False )
+			self.ui.btnNext.setEnabled( False )
 		QtCore.QObject.connect(self.ui.listStations, QtCore.SIGNAL('activated(int)'), self.playStation)
 		QtCore.QObject.connect(self.ui.btnNext, QtCore.SIGNAL('pressed()'), self.nextDown)
 		QtCore.QObject.connect(self.ui.btnNext, QtCore.SIGNAL('released()'), self.nextUp)
@@ -221,10 +251,10 @@ class Panda(QtGui.QMainWindow):
 			self.player.tiredSong = 1
 
 	def setSnooze(self):
-		time,ok = QtGui.QInputDialog.getText(self,"Snooze", "Enter a time, in minutes, to shutdown:")
+		ktime,ok = QtGui.QInputDialog.getText(self,"Snooze", "Enter a time, in minutes, to shutdown:")
 		if ok:
 			self.s.cont = 1
-			self.s.time = int(time)
+			self.s.ktime = int(ktime)
 			self.s.start()
 
 	def doFM(self):
@@ -300,6 +330,7 @@ class Panda(QtGui.QMainWindow):
 		self.player.user = self.c.user
 		self.player.password = self.c.password
 		self.player.doAuth = 1
+		self.authenticated = True
 		self.c.write()
 
 	def playStation( self ):
@@ -335,6 +366,13 @@ class Panda(QtGui.QMainWindow):
 		self.ui.btnHate.setEnabled( True )
 		self.ui.btnSleep.setEnabled( True )
 		self.ui.btnNext.setEnabled( True )
+
+		self.buildPlaylist()
+
+		if self.player.playStation > 0:
+			self.playStation()
+
+	def buildPlaylist( self ):
 		for s in self.player.stations:
 			if s["isQuickMix"]:
 				qMixIds = s["quickMixStationIds"]
@@ -349,10 +387,8 @@ class Panda(QtGui.QMainWindow):
 					sName += " *"
 			self.ui.listStations.addItem(sName)
 			if self.player.playStation>0 and s["stationId"] == self.player.playStation:
-				self.ui.listStations.setCurrentIndex(self.ui.listStations.count()-1)
-		if self.player.playStation > 0:
-			self.playStation()
-	
+				self.ui.listStations.setCurrentIndex(self.ui.listStations.count()-1)	
+
 	def setUserPass( self ):
 		self.c.user = ""
 		self.c.password = ""
@@ -361,11 +397,18 @@ class Panda(QtGui.QMainWindow):
 	def playNextSong( self ):
 		if not self.player.playing:
 			raise PandaException()
-		while len( self.player.playlist ) == 0:
-			time ( 0.5 )
+		while self.player.playlist == []:
+			self.player.getPlaylist = 1
+			time.sleep( 0.5 )
 		next = self.player.playlist.pop( 0 )
 		self.player.curSong = next
 		self.player.startPlay = 1
+		self.setUi ( next )
+		if len( self.player.playlist ) == 0:
+			#Out of songs, grab some more while playing
+			self.player.getPlaylist = 1
+	
+	def setUi ( self, next=None ):
 		art = next[1]["art"]
 		self.ui.albumArt.setHtml("<img style='width: 100%; height: 95%' src='"+art+"'>")
 		self.ui.lblAlbum.setText("\"" + next[1]["title"] + "\"" + " by " + next[1]["artist"] + "\n" + "on: " + next[1]["album"])
@@ -378,9 +421,6 @@ class Panda(QtGui.QMainWindow):
 			self.ui.btnLove.setStyleSheet("background-image: url(:/img/img/Thumbs-up-right-trans.png);\nborder: rgb(0, 0, 0);\nbackground-color: rgb(0, 0, 0);")
 
 		self.ui.btnPlay.setStyleSheet("background-image: url(:/img/img/playing-trans.png);\nborder: rgb(0, 0, 0);\nbackground-color: "+ self.c.color + ";")
-		if len( self.player.playlist ) == 0:
-			#Out of songs, grab some more while playing
-			self.player.getPlaylist = 1
 
 	def skipSong( self ):
 		self.player.skip = True
