@@ -117,7 +117,6 @@ class RadioPlayer(QtCore.QThread):
 
 	def play( self, url, item ):
 		self.player.set_property('uri', url)
-		time.sleep( 3 )
 		self.player.set_state(gst.STATE_PLAYING)
 
 	def stopPlayBack ( self,state=None ):
@@ -133,6 +132,7 @@ class RadioPlayer(QtCore.QThread):
 		if self.playing:
 			if self.skip:
 				self.skip = 0
+			time.sleep( 0.5 )
 			self.emit(QtCore.SIGNAL("PlayNext"))
 
 	def onPlayBackEnded( self, bus, msg ):
@@ -140,6 +140,7 @@ class RadioPlayer(QtCore.QThread):
 			if self.skip:
 				self.skip = 0
 			self.player.set_state(gst.STATE_NULL)
+			time.sleep( 0.5 )
 			self.emit(QtCore.SIGNAL("PlayNext"))
 
 	def LoveHate( self ):
